@@ -21,14 +21,6 @@ const (
 	withoutSessionToken withSessionTokenType = false
 )
 
-type unsupportedVersionError struct {
-	version *semver.Version
-}
-
-func (e unsupportedVersionError) Error() string {
-	return fmt.Sprintf("%s: unsupported version", e.version)
-}
-
 var onepasswordVersionRx = regexp.MustCompile(`^(\d+\.\d+\.\d+\S*)`)
 
 type onepasswordConfig struct {
@@ -64,8 +56,7 @@ type onepasswordItemV2 struct {
 func (c *Config) onepasswordTemplateFunc(userArgs ...string) map[string]interface{} {
 	version, err := c.onepasswordVersion()
 	if err != nil {
-		raiseTemplateError(err)
-		return nil
+		panic(err)
 	}
 
 	var baseArgs []string
@@ -75,28 +66,24 @@ func (c *Config) onepasswordTemplateFunc(userArgs ...string) map[string]interfac
 	case version.Major >= 2:
 		baseArgs = []string{"item", "get", "--format", "json"}
 	default:
-		raiseTemplateError(unsupportedVersionError{
+		panic(&unsupportedVersionError{
 			version: version,
 		})
-		return nil
 	}
 
 	args, err := newOnepasswordArgs(baseArgs, userArgs)
 	if err != nil {
-		raiseTemplateError(err)
-		return nil
+		panic(err)
 	}
 
 	output, err := c.onepasswordOutput(args, withSessionToken)
 	if err != nil {
-		raiseTemplateError(err)
-		return nil
+		panic(err)
 	}
 
 	var data map[string]interface{}
 	if err := json.Unmarshal(output, &data); err != nil {
-		raiseTemplateError(newParseCmdOutputError(c.Onepassword.Command, args.args, output, err))
-		return nil
+		panic(newParseCmdOutputError(c.Onepassword.Command, args.args, output, err))
 	}
 	return data
 }
@@ -104,16 +91,14 @@ func (c *Config) onepasswordTemplateFunc(userArgs ...string) map[string]interfac
 func (c *Config) onepasswordDetailsFieldsTemplateFunc(userArgs ...string) map[string]interface{} {
 	version, err := c.onepasswordVersion()
 	if err != nil {
-		raiseTemplateError(err)
-		return nil
+		panic(err)
 	}
 
 	switch {
 	case version.Major == 1:
 		item, err := c.onepasswordItemV1(userArgs)
 		if err != nil {
-			raiseTemplateError(err)
-			return nil
+			panic(err)
 		}
 
 		result := make(map[string]interface{})
@@ -127,8 +112,7 @@ func (c *Config) onepasswordDetailsFieldsTemplateFunc(userArgs ...string) map[st
 	case version.Major >= 2:
 		item, err := c.onepasswordItemV2(userArgs)
 		if err != nil {
-			raiseTemplateError(err)
-			return nil
+			panic(err)
 		}
 
 		result := make(map[string]interface{})
@@ -143,18 +127,16 @@ func (c *Config) onepasswordDetailsFieldsTemplateFunc(userArgs ...string) map[st
 		return result
 
 	default:
-		raiseTemplateError(unsupportedVersionError{
+		panic(&unsupportedVersionError{
 			version: version,
 		})
-		return nil
 	}
 }
 
 func (c *Config) onepasswordDocumentTemplateFunc(userArgs ...string) string {
 	version, err := c.onepasswordVersion()
 	if err != nil {
-		raiseTemplateError(err)
-		return ""
+		panic(err)
 	}
 
 	var baseArgs []string
@@ -164,22 +146,19 @@ func (c *Config) onepasswordDocumentTemplateFunc(userArgs ...string) string {
 	case version.Major >= 2:
 		baseArgs = []string{"document", "get"}
 	default:
-		raiseTemplateError(unsupportedVersionError{
+		panic(&unsupportedVersionError{
 			version: version,
 		})
-		return ""
 	}
 
 	args, err := newOnepasswordArgs(baseArgs, userArgs)
 	if err != nil {
-		raiseTemplateError(err)
-		return ""
+		panic(err)
 	}
 
 	output, err := c.onepasswordOutput(args, withSessionToken)
 	if err != nil {
-		raiseTemplateError(err)
-		return ""
+		panic(err)
 	}
 	return string(output)
 }
@@ -187,16 +166,14 @@ func (c *Config) onepasswordDocumentTemplateFunc(userArgs ...string) string {
 func (c *Config) onepasswordItemFieldsTemplateFunc(userArgs ...string) map[string]interface{} {
 	version, err := c.onepasswordVersion()
 	if err != nil {
-		raiseTemplateError(err)
-		return nil
+		panic(err)
 	}
 
 	switch {
 	case version.Major == 1:
 		item, err := c.onepasswordItemV1(userArgs)
 		if err != nil {
-			raiseTemplateError(err)
-			return nil
+			panic(err)
 		}
 
 		result := make(map[string]interface{})
@@ -212,8 +189,7 @@ func (c *Config) onepasswordItemFieldsTemplateFunc(userArgs ...string) map[strin
 	case version.Major >= 2:
 		item, err := c.onepasswordItemV2(userArgs)
 		if err != nil {
-			raiseTemplateError(err)
-			return nil
+			panic(err)
 		}
 
 		result := make(map[string]interface{})
@@ -228,10 +204,9 @@ func (c *Config) onepasswordItemFieldsTemplateFunc(userArgs ...string) map[strin
 		return result
 
 	default:
-		raiseTemplateError(unsupportedVersionError{
+		panic(&unsupportedVersionError{
 			version: version,
 		})
-		return nil
 	}
 }
 
@@ -384,13 +359,18 @@ func (c *Config) onepasswordVersion() (*semver.Version, error) {
 
 	m := onepasswordVersionRx.FindSubmatch(output)
 	if m == nil {
-		c.Onepassword.versionErr = fmt.Errorf("%q: cannot extract version", bytes.TrimSpace(output))
+		c.Onepassword.versionErr = &extractVersionError{
+			output: output,
+		}
 		return nil, c.Onepassword.versionErr
 	}
 
 	version, err := semver.NewVersion(string(m[1]))
 	if err != nil {
-		c.Onepassword.versionErr = fmt.Errorf("%q: cannot parse version: %w", m[1], err)
+		c.Onepassword.versionErr = &parseVersionError{
+			output: m[1],
+			err:    err,
+		}
 		return nil, c.Onepassword.versionErr
 	}
 
